==> haskell-hspec-2.2.3-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hspec.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec
version: 2.2.3
id: hspec-2.2.3-HUXCroEDj3S9OZd1QzI7ht
key: hspec-2.2.3-HUXCroEDj3S9OZd1QzI7ht
license: MIT
copyright: (c) 2011-2015 Simon Hengel,
           (c) 2011-2012 Trystan Spangler,
           (c) 2011 Greg Weber
maintainer: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: http://hspec.github.io/
synopsis: A Testing Framework for Haskell
description:
    Hspec is a testing framework for Haskell. It is inspired by
    the Ruby library RSpec. Some of Hspec'\''s distinctive features
    are:
    .
    * a friendly DSL for defining tests
    .
    * integration with QuickCheck, SmallCheck, and HUnit
    .
    * parallel test execution
    .
    * automatic discovery of test files
    .
    The Hspec Manual is at <http://hspec.github.io/>.
category: Testing
exposed: True
exposed-modules:
    Test.Hspec Test.Hspec.Runner Test.Hspec.Formatters
    Test.Hspec.QuickCheck Test.Hspec.Discover Test.Hspec.Core
    Test.Hspec.HUnit
abi: 0caf854ec15f25101665af3b7c438505
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/hspec-2.2.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/hspec-2.2.3
data-dir: /usr/share/arm-linux-ghc-8.0.1/hspec-2.2.3
hs-libraries: HShspec-2.2.3-HUXCroEDj3S9OZd1QzI7ht
depends:
    HUnit-1.3.1.2-5bcdqLN1PYT5H95JC2tBVg
    QuickCheck-2.9.2-AzbjWrJo3WFD60ZxKurQ3s base-4.9.0.0
    hspec-core-2.2.3-7i8vVMgmVbw3smRMe66PFX
    hspec-discover-2.2.3-4rui0mszaOW7JLbEGhMbpG
    hspec-expectations-0.7.2-1GrqRCOEyCN1xJdwurhSKa
    transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-hspec/html/hspec.haddock
haddock-html: /usr/share/doc/haskell-hspec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-2.2.4-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hspec.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec
version: 2.2.4
id: hspec-2.2.4-HsWxtqjeFxC8uWXIlrWThB
key: hspec-2.2.4-HsWxtqjeFxC8uWXIlrWThB
license: MIT
copyright: (c) 2011-2015 Simon Hengel,
           (c) 2011-2012 Trystan Spangler,
           (c) 2011 Greg Weber
maintainer: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: http://hspec.github.io/
synopsis: A Testing Framework for Haskell
description:
    Hspec is a testing framework for Haskell. It is inspired by
    the Ruby library RSpec. Some of Hspec'\''s distinctive features
    are:
    .
    * a friendly DSL for defining tests
    .
    * integration with QuickCheck, SmallCheck, and HUnit
    .
    * parallel test execution
    .
    * automatic discovery of test files
    .
    The Hspec Manual is at <http://hspec.github.io/>.
category: Testing
exposed: True
exposed-modules:
    Test.Hspec Test.Hspec.Core Test.Hspec.Discover
    Test.Hspec.Formatters Test.Hspec.HUnit Test.Hspec.QuickCheck
    Test.Hspec.Runner
hidden-modules: Paths_hspec
abi: ce66be24f17df42fd399d4f88275d9be
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/hspec-2.2.4
library-dirs: /usr/lib/ghc-8.0.1/site-local/hspec-2.2.4
data-dir: /usr/share/arm-linux-ghc-8.0.1/hspec-2.2.4
hs-libraries: HShspec-2.2.4-HsWxtqjeFxC8uWXIlrWThB
depends:
    HUnit-1.3.1.2-5bcdqLN1PYT5H95JC2tBVg
    QuickCheck-2.9.2-AzbjWrJo3WFD60ZxKurQ3s base-4.9.0.0
    hspec-core-2.2.4-7O6n7gLiGUoEjvrkecGhNG
    hspec-discover-2.2.4-6OsWF6p1kycGNLQpxduJUs
    hspec-expectations-0.7.2-1GrqRCOEyCN1xJdwurhSKa
    transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-hspec/html/hspec.haddock
haddock-html: /usr/share/doc/haskell-hspec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
